@@ -42,7 +42,8 @@ class BaseCheckRegistry(object):
 
         for entity in check.supported_entities:
             checks = self.wildcard_checks if self._is_wildcard(entity) else self.checks
-            checks[entity].append(check)
+            if not any(c.id == check.id for c in checks[entity]):
+                checks[entity].append(check)
 
     @staticmethod
     def _is_wildcard(entity):
@@ -90,8 +91,14 @@ class BaseCheckRegistry(object):
         raise NotImplementedError()
 
     def scan(self, scanned_file, entity, skipped_checks, runner_filter):
+
         (entity_type, entity_name, entity_configuration) = self.extract_entity_details(entity)
+
         results = {}
+
+        if not isinstance(entity_configuration, dict):
+            return results
+
         checks = self.get_checks(entity_type)
         for check in checks:
             skip_info = {}
@@ -104,7 +111,7 @@ class BaseCheckRegistry(object):
                 results[check] = result
         return results
 
-    def run_check(self, check, entity_configuration, entity_name, entity_type, scanned_file, skip_info):
+    def run_check(self, check, entity_configuration, entity_name, entity_type, scanned_file, skip_info, tags=None):
         self.logger.debug("Running check: {} on file {}".format(check.name, scanned_file))
         result = check.run(scanned_file=scanned_file, entity_configuration=entity_configuration,
                            entity_name=entity_name, entity_type=entity_type, skip_info=skip_info)
@@ -128,7 +135,7 @@ class BaseCheckRegistry(object):
             return True
         return False
 
-    def load_external_checks(self, directory, runner_filter):
+    def load_external_checks(self, directory):
         """ Browse a directory looking for .py files to import.
 
         Log an error when the directory does not contains an __init__.py or
