@@ -83,12 +83,16 @@ class RunnerRegistry(object):
     def filter_runner_framework(self):
         if not self.runner_filter:
             return
+        if self.runner_filter.framework is None:
+            return
         if self.runner_filter.framework == 'all':
             return
+        filtered_runners = []
         for runner in self.runners:
-            if runner.check_type == self.runner_filter.framework:
-                self.runners = [runner]
-                return
+            if runner.check_type in self.runner_filter.framework:
+                filtered_runners.append(runner)
+        self.runners = filtered_runners
+        return
 
     @staticmethod
     def enrich_report_with_guidelines(scan_report, guidelines):
