@@ -14,7 +14,7 @@ class ReadinessProbe(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-        return conf['parent']
+        return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
         # Don't check Job/CronJob (or Pods in runtime derived from Job/CronJob)
@@ -30,4 +30,5 @@ class ReadinessProbe(BaseK8Check):
             return CheckResult.FAILED
         return CheckResult.PASSED
 
-check = ReadinessProbe()
\ No newline at end of file
+
+check = ReadinessProbe()
